diff -Naur firewalld-0.4.4.4/config/firewalld.init firewalld-0.4.4.4-confd/config/firewalld.init
--- firewalld-0.4.4.4/config/firewalld.init	2017-03-27 19:17:41.000000000 +0200
+++ firewalld-0.4.4.4-confd/config/firewalld.init	2017-05-18 13:42:39.643047882 +0200
@@ -29,7 +29,7 @@
 prog="firewalld"
 #config="/etc/firewalld/firewalld.conf"
 
-[ -e /etc/sysconfig/$prog ] && . /etc/sysconfig/$prog
+[ -e /etc/conf.d/$prog ] && . /etc/conf.d/$prog
 
 lockfile=/var/lock/subsys/$prog
 
diff -Naur firewalld-0.4.4.4/config/firewalld.service.in firewalld-0.4.4.4-confd/config/firewalld.service.in
--- firewalld-0.4.4.4/config/firewalld.service.in	2017-03-27 19:17:41.000000000 +0200
+++ firewalld-0.4.4.4-confd/config/firewalld.service.in	2017-05-18 13:42:54.438886706 +0200
@@ -8,7 +8,7 @@
 Documentation=man:firewalld(1)
 
 [Service]
-EnvironmentFile=-/etc/sysconfig/firewalld
+EnvironmentFile=-/etc/conf.d/firewalld
 ExecStart=@sbindir@/firewalld --nofork --nopid $FIREWALLD_ARGS
 ExecReload=/bin/kill -HUP $MAINPID
 # supress to log debug and error output also to /var/log/messages
diff -Naur firewalld-0.4.4.4/config/Makefile.am firewalld-0.4.4.4-confd/config/Makefile.am
--- firewalld-0.4.4.4/config/Makefile.am	2017-03-27 19:17:41.000000000 +0200
+++ firewalld-0.4.4.4-confd/config/Makefile.am	2017-05-18 13:44:04.884122732 +0200
@@ -275,12 +275,12 @@
 	$(edit) $< >$@
 
 install-sysconfig:
-	$(MKDIR_P) $(DESTDIR)$(sysconfdir)/sysconfig
-	$(INSTALL_DATA) $(srcdir)/firewalld.sysconfig $(DESTDIR)$(sysconfdir)/sysconfig/firewalld
+	$(MKDIR_P) $(DESTDIR)$(sysconfdir)/conf.d
+	$(INSTALL_DATA) $(srcdir)/firewalld.sysconfig $(DESTDIR)$(sysconfdir)/conf.d/firewalld
 
 uninstall-sysconfig:
-	rm -f $(DESTDIR)$(sysconfdir)/sysconfig/firewalld
-	rmdir $(DESTDIR)$(sysconfdir)/sysconfig || :
+	rm -f $(DESTDIR)$(sysconfdir)/conf.d/firewalld
+	rmdir $(DESTDIR)$(sysconfdir)/conf.d || :
 
 install-rpmmacros:
 	$(MKDIR_P) $(DESTDIR)$(prefix)/lib/rpm/macros.d
diff -Naur firewalld-0.4.4.4/doc/xml/firewall-cmd.xml firewalld-0.4.4.4-confd/doc/xml/firewall-cmd.xml
--- firewalld-0.4.4.4/doc/xml/firewall-cmd.xml	2017-03-27 19:17:41.000000000 +0200
+++ firewalld-0.4.4.4-confd/doc/xml/firewall-cmd.xml	2017-05-18 13:45:53.477954732 +0200
@@ -900,7 +900,7 @@
 	    </para>
 	    <para>
 	      As a end user you don't need this in most cases, because NetworkManager (or legacy network service) adds interfaces into zones automatically (according to <option>ZONE=</option> option from ifcfg-<replaceable>interface</replaceable> file) if <replaceable>NM_CONTROLLED=no</replaceable> is not set.
-	      You should do it only if there's no /etc/sysconfig/network-scripts/ifcfg-<replaceable>interface</replaceable> file.
+	      You should do it only if there's no /etc/conf.d/network-scripts/ifcfg-<replaceable>interface</replaceable> file.
 	      If there is such file and you add interface to zone with this <option>--add-interface</option> option, make sure the zone is the same in both cases, otherwise the behaviour would be undefined.
 	      Please also have a look at the <citerefentry><refentrytitle>firewalld</refentrytitle><manvolnum>1</manvolnum></citerefentry> man page in the <replaceable>Concepts</replaceable> section.
 	      For permanent association of interface with a zone, see also 'How to set or change a zone for a connection?' in <citerefentry><refentrytitle>firewalld.zones</refentrytitle><manvolnum>5</manvolnum></citerefentry>.
diff -Naur firewalld-0.4.4.4/doc/xml/firewallctl.xml firewalld-0.4.4.4-confd/doc/xml/firewallctl.xml
--- firewalld-0.4.4.4/doc/xml/firewallctl.xml	2017-03-27 19:17:41.000000000 +0200
+++ firewalld-0.4.4.4-confd/doc/xml/firewallctl.xml	2017-05-18 13:46:13.166744073 +0200
@@ -601,7 +601,7 @@
 	    </para>
 	    <para>
 	      As a end user you don't need to create or change zone bindings of interfaces in most cases, because NetworkManager (or legacy network service) adds interfaces into zones automatically (according to <option>ZONE=</option> option from ifcfg-<replaceable>interface</replaceable> file) if <replaceable>NM_CONTROLLED=no</replaceable> is not set.
-	      You should do it only if there's no /etc/sysconfig/network-scripts/ifcfg-<replaceable>interface</replaceable> file.
+	      You should do it only if there's no /etc/conf.d/network-scripts/ifcfg-<replaceable>interface</replaceable> file.
 	      If there is such file and you add interface to zone with this <option>--add-interface</option> option, make sure the zone is the same in both cases, otherwise the behaviour would be undefined.
 	      Please also have a look at the <citerefentry><refentrytitle>firewalld</refentrytitle><manvolnum>1</manvolnum></citerefentry> man page in the <replaceable>Concepts</replaceable> section.
 	      For permanent association of interface with a zone, see also 'How to set or change a zone for a connection?' in <citerefentry><refentrytitle>firewalld.zones</refentrytitle><manvolnum>5</manvolnum></citerefentry>.
diff -Naur firewalld-0.4.4.4/doc/xml/firewalld.xml firewalld-0.4.4.4-confd/doc/xml/firewalld.xml
--- firewalld-0.4.4.4/doc/xml/firewalld.xml	2017-03-27 19:17:41.000000000 +0200
+++ firewalld-0.4.4.4-confd/doc/xml/firewalld.xml	2017-05-18 13:45:27.919228681 +0200
@@ -130,7 +130,7 @@
     </para>
     <para>
       You can add these interfaces to a zone with <command>firewall-cmd [--permanent] --zone=<replaceable>zone</replaceable> --add-interface=<replaceable>interface</replaceable></command>.
-      If there is a /etc/sysconfig/network-scripts/ifcfg-<replaceable>interface</replaceable> file, firewalld tries to change the ZONE=<replaceable>zone</replaceable> setting in this file.
+      If there is a /etc/conf.d/network-scripts/ifcfg-<replaceable>interface</replaceable> file, firewalld tries to change the ZONE=<replaceable>zone</replaceable> setting in this file.
     </para>
     <para>
       If firewalld gets reloaded, it will restore the interface bindings that were in place before reloading to keep interface bindings stable in the case of NetworkManager uncontrolled interfaces.
diff -Naur firewalld-0.4.4.4/doc/xml/firewall-offline-cmd.xml firewalld-0.4.4.4-confd/doc/xml/firewall-offline-cmd.xml
--- firewalld-0.4.4.4/doc/xml/firewall-offline-cmd.xml	2017-03-27 19:17:41.000000000 +0200
+++ firewalld-0.4.4.4-confd/doc/xml/firewall-offline-cmd.xml	2017-05-18 13:45:41.549082524 +0200
@@ -68,7 +68,7 @@
   <refsect1 id="options">
     <title>Options</title>
     <para>
-      If no options are given, configuration from <command>/etc/sysconfig/system-config-firewall</command> will be migrated.
+      If no options are given, configuration from <command>/etc/conf.d/system-config-firewall</command> will be migrated.
     </para>
 
     <para>
diff -Naur firewalld-0.4.4.4/src/firewall/config/__init__.py.in firewalld-0.4.4.4-confd/src/firewall/config/__init__.py.in
--- firewalld-0.4.4.4/src/firewall/config/__init__.py.in	2017-03-27 19:17:41.000000000 +0200
+++ firewalld-0.4.4.4-confd/src/firewall/config/__init__.py.in	2017-05-18 13:47:28.374942140 +0200
@@ -87,7 +87,7 @@
 
 LOCKDOWN_WHITELIST = ETC_FIREWALLD + '/lockdown-whitelist.xml'
 
-SYSCONFIGDIR = '/etc/sysconfig'
+SYSCONFIGDIR = '/etc/conf.d'
 IFCFGDIR = SYSCONFIGDIR + '/network-scripts'
 
 SYSCTL_CONFIG = '/etc/sysctl.conf'
diff -Naur firewalld-0.4.4.4/src/tests/firewall-offline-cmd_test.sh firewalld-0.4.4.4-confd/src/tests/firewall-offline-cmd_test.sh
--- firewalld-0.4.4.4/src/tests/firewall-offline-cmd_test.sh	2017-03-27 19:17:41.000000000 +0200
+++ firewalld-0.4.4.4-confd/src/tests/firewall-offline-cmd_test.sh	2017-05-18 13:46:51.941330110 +0200
@@ -190,7 +190,7 @@
 failures=0
 
 while true; do
-    read -p "This test overwrites your /etc/firewalld/zones/* and /etc/sysconfig/system-config-firewall. Do you want to continue ?" yn
+    read -p "This test overwrites your /etc/firewalld/zones/* and /etc/conf.d/system-config-firewall. Do you want to continue ?" yn
     case $yn in
         [Yy]* ) break;;
         [Nn]* ) exit;;
@@ -215,14 +215,14 @@
 lokkit_opts="--enabled --addmodule=abc --addmodule=efg --removemodule=xyz
  --trust=${trusted_iface1} --trust=${trusted_iface2}
  --masq=tun+ --masq=tap+ --port=7:tcp --port=666:udp
- --custom-rules=ipv4:mangle:/etc/sysconfig/ebtables-config
+ --custom-rules=ipv4:mangle:/etc/conf.d/ebtables-config
  --service=${service1} --service=${service2} --remove-service=${service3}
  --block-icmp=${icmp1} --block-icmp=${icmp2}
  --forward-port=if=ippp+:${fw_port1}
  --forward-port=if=ippp+:${fw_port2}"
 test_lokkit_opts
 
-cat << EOF > /etc/sysconfig/system-config-firewall
+cat << EOF > /etc/conf.d/system-config-firewall
 --enabled
 --addmodule=abc
 --addmodule=efg
@@ -233,7 +233,7 @@
 --masq=tap+
 --port=7:tcp
 --port=666:udp
---custom-rules=ipv4:mangle:/etc/sysconfig/ebtables-config
+--custom-rules=ipv4:mangle:/etc/conf.d/ebtables-config
 --service=${service1}
 --service=${service2}
 --remove-service=${service3}
@@ -243,7 +243,7 @@
 --forward-port=if=ippp+:${fw_port2}
 EOF
 
 # running firewall-offline-cmd without options should import /etc/sysconfig/system-config-firewall
 lokkit_opts=""
 test_lokkit_opts
 
@@ -243,7 +243,7 @@
 EOF
 
-# running firewall-offline-cmd without options should import /etc/sysconfig/system-config-firewall
+# running firewall-offline-cmd without options should import /etc/conf.d/system-config-firewall
 lokkit_opts=""
 test_lokkit_opts
